@@ -14,7 +14,6 @@
 #    under the License.
 
 from os_brick.encryptors import cryptsetup
-from os_brick.i18n import _LI, _LW
 from os_brick.privileged import rootwrap as priv_rootwrap
 from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
@@ -38,8 +37,8 @@ def is_luks(root_helper, device, execute=None):
                 check_exit_code=True)
         return True
     except putils.ProcessExecutionError as e:
-        LOG.warning(_LW("isLuks exited abnormally (status %(exit_code)s): "
-                        "%(stderr)s"),
+        LOG.warning("isLuks exited abnormally (status %(exit_code)s): "
+                    "%(stderr)s",
                     {"exit_code": e.exit_code, "stderr": e.stderr})
         return False
 
@@ -157,8 +156,8 @@ class LuksEncryptor(cryptsetup.CryptsetupEncryptor):
                                                 self.dev_path,
                                                 execute=self._execute):
                 # the device has never been formatted; format it and try again
-                LOG.info(_LI("%s is not a valid LUKS device;"
-                             " formatting device for first use"),
+                LOG.info("%s is not a valid LUKS device;"
+                         " formatting device for first use",
                          self.dev_path)
                 self._format_volume(passphrase, **kwargs)
                 self._open_volume(passphrase, **kwargs)
@@ -166,9 +165,9 @@ class LuksEncryptor(cryptsetup.CryptsetupEncryptor):
                 # NOTE(lyarwood): Workaround bug#1633518 by replacing any
                 # mangled passphrases that are found on the volume.
                 # TODO(lyarwood): Remove workaround during R.
-                LOG.warning(_LW("%s is not usable with the current "
-                                "passphrase, attempting to use a mangled "
-                                "passphrase to open the volume."),
+                LOG.warning("%s is not usable with the current "
+                            "passphrase, attempting to use a mangled "
+                            "passphrase to open the volume.",
                             self.dev_path)
                 self._unmangle_volume(key, passphrase, **kwargs)
                 self._open_volume(passphrase, **kwargs)
@@ -184,12 +183,7 @@ class LuksEncryptor(cryptsetup.CryptsetupEncryptor):
     def _close_volume(self, **kwargs):
         """Closes the device (effectively removes the dm-crypt mapping)."""
         LOG.debug("closing encrypted volume %s", self.dev_path)
-        # NOTE(mdbooth): luksClose will return 4 (wrong device specified) if
-        # the device doesn't exist. We assume here that the caller hasn't
-        # specified the wrong device, and that it doesn't exist because it
-        # isn't open. We don't fail in this case in order to make this
-        # operation idempotent.
         self._execute('cryptsetup', 'luksClose', self.dev_name,
-                      run_as_root=True, check_exit_code=[0, 4],
+                      run_as_root=True, check_exit_code=True,
                       root_helper=self._root_helper,
                       attempts=3)
