@@ -16,7 +16,7 @@
 
 import six
 
-from os_brick.i18n import _, _LE
+from os_brick.i18n import _
 from oslo_log import log as logging
 
 
@@ -51,11 +51,11 @@ class BrickException(Exception):
             except Exception:
                 # kwargs doesn't match a variable in the message
                 # log the issue and the kwargs
-                LOG.exception(_LE("Exception in string format operation. "
-                                  "msg='%s'"), self.message)
+                LOG.exception("Exception in string format operation. "
+                              "msg='%s'", self.message)
                 for name, value in kwargs.items():
-                    LOG.error(_LE("%(name)s: %(value)s"), {'name': name,
-                                                           'value': value})
+                    LOG.error("%(name)s: %(value)s", {'name': name,
+                                                      'value': value})
 
                 # at least get the core message out if something happened
                 message = self.message
@@ -94,6 +94,10 @@ class NoFibreChannelVolumeDeviceFound(BrickException):
     message = _("Unable to find a Fibre Channel volume device.")
 
 
+class VolumeNotDeactivated(BrickException):
+    message = _('Volume %(name)s was not deactivated in time.')
+
+
 class VolumeDeviceNotFound(BrickException):
     message = _("Volume device not found at %(device)s.")
 
@@ -150,3 +154,16 @@ class InvalidIOHandleObject(BrickException):
 class VolumeEncryptionNotSupported(Invalid):
     message = _("Volume encryption is not supported for %(volume_type)s "
                 "volume %(volume_id)s.")
+
+
+# NOTE(mriedem): This extends ValueError to maintain backward compatibility.
+class InvalidConnectorProtocol(ValueError):
+    pass
+
+
+class HostChannelsTargetsNotFound(BrickException):
+    message = _('Unable to find host, channel, and target for %(iqns)s.')
+
+    def __init__(self, message=None, iqns=None, found=None):
+        super(HostChannelsTargetsNotFound, self).__init__(message, iqns=iqns)
+        self.found = found
