@@ -29,6 +29,7 @@ from oslo_concurrency import lockutils
 from oslo_log import log as logging
 from oslo_utils import importutils
 
+from os_brick import exception
 from os_brick.i18n import _
 from os_brick import initiator
 from os_brick import utils
@@ -97,6 +98,7 @@ connector_list = [
     'os_brick.initiator.windows.iscsi.WindowsISCSIConnector',
     'os_brick.initiator.windows.fibre_channel.WindowsFCConnector',
     'os_brick.initiator.windows.smbfs.WindowsSMBFSConnector',
+    'os_brick.initiator.connectors.vrtshyperscale.HyperScaleConnector',
 ]
 
 # Mappings used to determine who to contruct in the factory
@@ -142,7 +144,8 @@ _connector_mapping_linux = {
         'os_brick.initiator.connectors.vmware.VmdkConnector',
     initiator.GPFS:
         'os_brick.initiator.connectors.gpfs.GPFSConnector',
-
+    initiator.VERITAS_HYPERSCALE:
+        'os_brick.initiator.connectors.vrtshyperscale.HyperScaleConnector',
 }
 
 # Mapping for the S390X platform
@@ -282,7 +285,7 @@ class InitiatorConnector(object):
             msg = (_("Invalid InitiatorConnector protocol "
                      "specified %(protocol)s") %
                    dict(protocol=protocol))
-            raise ValueError(msg)
+            raise exception.InvalidConnectorProtocol(msg)
 
         conn_cls = importutils.import_class(connector)
         return conn_cls(*args, **kwargs)
