@@ -21,8 +21,8 @@ from oslo_log import log as logging
 from oslo_utils import fileutils
 from oslo_utils import netutils
 
-from os_brick.i18n import _, _LE
 from os_brick import exception
+from os_brick.i18n import _
 from os_brick import initiator
 from os_brick.initiator.connectors import base
 from os_brick.initiator import linuxrbd
@@ -70,19 +70,24 @@ class RBDConnector(base.BaseLinuxConnector):
         return list(map(_sanitize_host, hosts))
 
     def _create_ceph_conf(self, monitor_ips, monitor_ports,
-                          cluster_name, user):
+                          cluster_name, user, keyring_path):
         monitors = ["%s:%s" % (ip, port) for ip, port in
                     zip(self._sanitize_mon_hosts(monitor_ips), monitor_ports)]
         mon_hosts = "mon_host = %s" % (','.join(monitors))
 
         client_section = "[client.%s]" % user
-        keyring = ("keyring = /etc/ceph/%s.client.%s.keyring" %
-                   (cluster_name, user))
+
+        if keyring_path is None:
+            keyring = ("keyring = /etc/ceph/%s.client.%s.keyring" %
+                       (cluster_name, user))
+        else:
+            keyring = "keyring = %s" % keyring_path
+
         try:
             fd, ceph_conf_path = tempfile.mkstemp(prefix="brickrbd_")
             with os.fdopen(fd, 'w') as conf_file:
                 conf_file.writelines([mon_hosts, "\n",
-                                      client_section, "\n", keyring])
+                                      client_section, "\n", keyring, "\n"])
             return ceph_conf_path
         except IOError:
             msg = (_("Failed to write data to %s.") % (ceph_conf_path))
@@ -95,12 +100,14 @@ class RBDConnector(base.BaseLinuxConnector):
             cluster_name = connection_properties.get('cluster_name')
             monitor_ips = connection_properties.get('hosts')
             monitor_ports = connection_properties.get('ports')
+            keyring_path = connection_properties.get('keyring')
         except IndexError:
             msg = _("Connect volume failed, malformed connection properties")
             raise exception.BrickException(msg=msg)
 
         conf = self._create_ceph_conf(monitor_ips, monitor_ports,
-                                      str(cluster_name), user)
+                                      str(cluster_name), user,
+                                      keyring_path)
         try:
             rbd_client = linuxrbd.RBDClient(user, pool, conffile=conf,
                                             rbd_cluster_name=str(cluster_name))
@@ -194,7 +201,7 @@ class RBDConnector(base.BaseLinuxConnector):
         try:
             rbd_handle.read(4096)
         except Exception as e:
-            LOG.error(_LE("Failed to access RBD device handle: %(error)s"),
+            LOG.error("Failed to access RBD device handle: %(error)s",
                       {"error": e})
             return False
         finally:
